@@ -1,6 +1,7 @@
 import os
 import json
 import tempfile
+import threading
 
 from flask import make_response, request
 
@@ -9,6 +10,7 @@ from slugify import slugify
 import ckan.model as model
 import ckan.plugins.toolkit as toolkit
 
+from ckan.common import config
 from ckan.logic import get_action, ValidationError
 from ckan.views.dataset import _tag_string_to_list
 
@@ -265,19 +267,26 @@ def publish_package():
         data_response['error_summary'] = e.error_summary
         data_response['has_error'] = True
     else:
-        validation = default_backend.validate_package(frictionless_package)
-        datapackage = model.Session.query(Datapackage).filter(
-            Datapackage.package_id==package_data['id']
-        ).order_by(Datapackage.created.desc()).first()
-        new_datapackage = Datapackage()
-        new_datapackage.package_id = package_data['id']
-        new_datapackage.errors = validation.to_dict()
-        if datapackage:
-            new_datapackage.data = datapackage.data
-        else:
-            new_datapackage.data = json.loads(metadata)
-        model.Session.add(new_datapackage)
-        model.Session.commit()
+        def _validate():
+            site_url = config.get('ckan.site_url')
+            if site_url.endswith('/'):
+                url = f"{site_url}datapackage-creator/show-datapackage-json/{data['id']}"
+            else:
+                url = f"{site_url}/datapackage-creator/show-datapackage-json/{data['id']}"
+            validation = default_backend.validate_package(url)
+            datapackage = model.Session.query(Datapackage).filter(
+                Datapackage.package_id==package_data['id']
+            ).order_by(Datapackage.created.desc()).first()
+            new_datapackage = Datapackage()
+            new_datapackage.package_id = package_data['id']
+            new_datapackage.errors = validation.to_dict()
+            if datapackage:
+                new_datapackage.data = datapackage.data
+            else:
+                new_datapackage.data = json.loads(metadata)
+            model.Session.add(new_datapackage)
+            model.Session.commit()
+        threading.Thread(target=_validate).start()
     response = make_response()
     response.content_type = 'application/json'
     response.data = json.dumps(data_response)
